/**
 *  Copyright (C) 2000-2012 The Software Conservancy and Original Authors.
 *  All rights reserved.
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 *
 *  Nothing in this notice shall be deemed to grant any rights to trademarks,
 *  copyrights, patents, trade secrets or any other intellectual property of the
 *  licensor or any contributor except as expressly stated herein. No patent
 *  license is granted separate from the Software, for code that you delete from
 *  the Software, or for combinations of the Software with other software or
 *  hardware.
 */
package org.chorusbdd.chorus.handlers.timers;

import org.chorusbdd.chorus.annotations.Handler;
import org.chorusbdd.chorus.annotations.HandlerScope;
import org.chorusbdd.chorus.annotations.Step;
import org.chorusbdd.chorus.util.logging.ChorusLog;
import org.chorusbdd.chorus.util.logging.ChorusLogFactory;

/**
 * Created by: Steve Neal
 * Date: 12/10/11
 */
@Handler(value = "Timers", scope = HandlerScope.UNMANAGED)
@SuppressWarnings("UnusedDeclaration")
public class TimersHandler {

    private static ChorusLog log = ChorusLogFactory.getLog(TimersHandler.class);

    /**
     * Simple timer to make the calling thread sleep
     *
     * @param seconds the number of seconds that the thread will sleep for
     */
    @Step(".*wait for ([0-9]*) seconds?.*")
    public void waitForSeconds(int seconds) {
        try {
            Thread.sleep(seconds * 1000);
        } catch (InterruptedException e) {
            log.error("Thread interrupted while sleeping", e);
        }
    }

    @Step(".*wait for ([0-9]*) milliseconds?.*")
    public void waitForMilliseconds(int millis) {
        try {
            Thread.sleep(millis);
        } catch (InterruptedException e) {
            log.error("Thread interrupted while sleeping", e);
        }
    }

    @Step(".*wait for half a second.*")
    public void waitForHalfASecond() {
       try {
           Thread.sleep(500);
       } catch (InterruptedException e) {
           log.error("Thread interrupted while sleeping", e);
       }
    }

}
